@@ -12,7 +12,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 sub ProcessFotoStation($$);
 
@@ -38,11 +38,13 @@ sub ProcessFotoStation($$);
     },
     0x03 => {
         Name => 'ThumbnailImage',
+        Groups => { 2 => 'Preview' },
         Writable => 1,
         RawConv => '$self->ValidateImage(\$val,$tag)',
     },
     0x04 => {
         Name => 'PreviewImage',
+        Groups => { 2 => 'Preview' },
         Writable => 1,
         RawConv => '$self->ValidateImage(\$val,$tag)',
     },
@@ -169,7 +171,7 @@ sub ProcessFotoStation($$)
             next;
         }
         if ($$et{DEL_GROUP}{FotoStation}) {
-            $verbose and printf $out "  Deleting FotoStation trailer\n";
+            $verbose and print $out "  Deleting FotoStation trailer\n";
             $verbose = 0;   # no more verbose messages after this
             ++$$et{CHANGED};
             next;
