@@ -19,7 +19,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.29';
+$VERSION = '1.30';
 
 sub ProcessRicohText($$$);
 sub ProcessRicohRMETA($$$);
@@ -87,7 +87,7 @@ my %ricohLensIDs = (
             2 => 'JPEG',
             3 => 'DNG',
         },
-    },            
+    },
     0x1001 => [{
         Name => 'ImageInfo',
         Condition => '$format ne "int16u"',
@@ -116,7 +116,7 @@ my %ricohLensIDs = (
             1 => 'Continuous',
             8 => 'AF-priority Continuous',
         },
-    },            
+    },
     0x1003 => [{
         Name => 'Sharpness',
         Condition => '$format ne "int16u"',
@@ -886,6 +886,7 @@ my %ricohLensIDs = (
     },
     thum => {
         Name => 'ThumbnailImage',
+        Groups => { 2 => 'Preview' },
         Binary => 1,
     },
 );
