@@ -9,7 +9,7 @@
 package Image::ExifTool::XMP;
 
 use strict;
-use vars qw(%specialStruct $xlatNamespace);
+use vars qw(%specialStruct %stdXlatNS);
 
 use Image::ExifTool qw(:Utils);
 use Image::ExifTool::XMP;
@@ -584,7 +584,7 @@ sub ConvertStruct($$$$;$)
             return $val;
         } else {
             my (@list, $val);
-            foreach $val (@$value) {    
+            foreach $val (@$value) {
                 my $v = ConvertStruct($et, $tagInfo, $val, $type, $parentID);
                 push @list, $v if defined $v;
             }
@@ -630,10 +630,12 @@ sub RestoreStruct($;$)
             # create new entry in tag table for this structure
             my $g1 = $$table{GROUPS}{0} || 'XMP';
             my $name = $tag;
+            # tag keys will have a group 1 prefix when coming from import of XML from -X option
             if ($tag =~ /(.+):(.+)/) {
                 my $ns;
                 ($ns, $name) = ($1, $2);
-                $ns = $$xlatNamespace{$ns} if $$xlatNamespace{$ns};
+                $ns =~ s/^XMP-//; # remove leading "XMP-" if it exists because we add it later
+                $ns = $stdXlatNS{$ns} if $stdXlatNS{$ns};
                 $g1 .= "-$ns";
             }
             $strInfo = {
@@ -725,7 +727,7 @@ sub RestoreStruct($;$)
                 # XMP namespace on the tag name.  In this case, add
                 # the corresponding group1 name to the tag ID.
                 my ($ns, $name) = ($1, $2);
-                $ns = $$xlatNamespace{$ns} if $$xlatNamespace{$ns};
+                $ns = $stdXlatNS{$ns} if $stdXlatNS{$ns};
                 $tag = "XMP-$ns:" . ucfirst $name;
             } else {
                 $tag = ucfirst $tag;
