@@ -24,10 +24,12 @@ require Exporter;
 use Image::ExifTool qw(ImageInfo);
 
 use vars qw($VERSION @ISA @EXPORT);
-$VERSION = '1.20';
+$VERSION = '1.21';
 @ISA = qw(Exporter);
 @EXPORT = qw(check writeCheck writeInfo testCompare binaryCompare testVerbose);
 
+my $noTimeLocal;
+
 sub nearEnough($$);
 sub nearTime($$$$);
 sub formatValue($);
@@ -112,7 +114,7 @@ sub testCompare($$$;$)
     
     # erase .failed file if test was successful
     $success and not $keep and unlink $testfile;
-    
+
     return $success
 }
 
@@ -129,8 +131,9 @@ sub nearEnough($$)
                ($line2 eq "$1$Image::ExifTool::VERSION$Image::ExifTool::RELEASE$2" or
                 $line2 eq "$1$Image::ExifTool::VERSION$2");
 
-    # allow different FileModifyDate, FileAccessDate and FilePermissions
-    return 1 if $line1 =~ /(File\s?(Modif.*Date|Access\s?Date|Permissions))/ and $line2 =~ /$1/;
+    # allow different FileModifyDate, FileAccessDate, FileCreateDate/FileInodeChangeDate and FilePermissions
+    return 1 if $line1 =~ /(File\s?(Modif.*Date|Access\s?Date|Inode\s?Change\s?Date|Permissions))/ and
+               ($line2 =~ /$1/ or $line2 =~ /File\s?Creat.*Date/);
 
     # allow CurrentIPTCDigest to be zero if Digest::MD5 isn't installed
     return 1 if $line1 =~ /Current IPTC Digest/ and
@@ -154,8 +157,16 @@ sub nearEnough($$)
             return 1 if $tok1=~ /^[-+]?\d+\./ or $tok2=~/^[-+]?\d+\./;  # check for float
             return $lenChanged
         }
+        if ($tok1 =~ /^(\d{2}|\d{4}):\d{2}:\d{2}/ and $tok2 =~ /^(\d{2}|\d{4}):\d{2}:\d{2}/ and
+            not eval { require Time::Local })
+        {
+            unless ($noTimeLocal) {
+                warn "Ignored time difference(s) because Time::Local is not installed\n";
+                $noTimeLocal = 1;
+            }
+            next;   # ignore times if Time::Local not available
         # account for different timezones
-        if ($tok1 =~ /^(\d{2}:\d{2}:\d{2})(Z|[-+]\d{2}:\d{2})$/i) {
+        } elsif ($tok1 =~ /^(\d{2}:\d{2}:\d{2})(Z|[-+]\d{2}:\d{2})$/i) {
             my $time = $1;  # remove timezone
             # timezone may be wrong if writing date/time value in a different timezone
             next if $tok2 =~ /^(\d{2}:\d{2}:\d{2})(Z|[-+]\d{2}:\d{2})$/i and $time eq $1;
